@@ -434,6 +434,7 @@ eel_preferences_set (const char *name,
 		eel_gconf_set_string (key, string_value);
 	}
 	g_free (key);
+	g_free (old_value);
 }
 
 char *
@@ -571,12 +572,8 @@ preferences_callback_entry_invoke_function (gpointer data,
 static void
 preferences_entry_invoke_callbacks (PreferencesEntry *entry)
 {
-	GConfValue *new_value;
-	
 	g_return_if_fail (entry != NULL);
 
-	new_value = preferences_get_value (entry->name);
-
 	/* Update the auto storage preferences */
 	if (entry->auto_storage_list != NULL) {
 		preferences_entry_update_auto_storage (entry);			
